@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 __author__ = "Paul Schifferer <dm@sweetrpg.com>"
-"""Web exceptions
+"""Constants.
 """
 
 
@@ -9,3 +9,5 @@ SESSION_EMAIL = "email"
 SESSION_USER_ID = "user_id"
 
 BUILD_INFO_PATH = "BUILD_INFO_PATH"
+APPLICATION_BASE_PATH = "APPLICATION_BASE_PATH"
+STATIC_ASSET_PREFIX = "STATIC_ASSET_PREFIX"
